@@ -1,19 +1,22 @@
 use config::Config;
 use dotenv::dotenv;
 use reqwest;
+use scheduler_service::run_schedulers;
 
+mod anime_link_service;
 mod anime_service;
 mod auth;
-mod config;
-mod handlers;
-mod model;
-mod routes;
-mod mal_api;
-mod model_dto;
 mod cache_service;
+mod config;
 mod file_storage_service;
-mod image_service;
 mod gemini_api;
+mod handlers;
+mod image_service;
+mod mal_api;
+mod model;
+mod model_dto;
+mod routes;
+mod scheduler_service;
 
 pub struct AppState {
     pub config: Config,
@@ -25,13 +28,13 @@ pub struct AppState {
 async fn main() {
     dotenv().ok();
 
-    let config = Config::init();
-    let app = routes::setup_app(config).await;
+    let config = Config::init().await;
+    let app = routes::setup_app(config.clone()).await;
 
     let port = std::env::var("PORT").unwrap_or_else(|_| "8001".to_string());
     let addr = format!("0.0.0.0:{}", port);
-
     println!("Server started at http://{}", addr);
     let listener = tokio::net::TcpListener::bind(addr).await.unwrap();
+    run_schedulers().await;
     axum::serve(listener, app).await.unwrap();
 }
